# random-mitype

Generate random word typing tests for [mitype](https://github.com/Mithil467/mitype), a terminal-based typing test
application.

## Installation

```
pip install mitype
```

and

```
pip install random-mitype
```

If `mitype` works for you, you should be able to run `random-mitype`.

```
Usage: random-mitype [OPTIONS] [WORDS]

  Start a typing test with number of WORDS.

Options:
  -v, --version  Show the version and exit.
  -h, --help     Show this message and exit.
```

## License

[MIT](https://github.com/RealCyGuy/random-mitype/blob/main/LICENSE.md)
